"""Console script for pyyawl."""
import argparse
import sys
from pathlib import Path
from pyyawl import pyyawl


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument('--generate', dest='generate', action='store_true')
    parser.add_argument('--f', type=Path)
    parser.add_argument('--verbose', dest='verbose', action='store_true')
    args = parser.parse_args()

    if args.generate:
        print(pyyawl.generate())
    else:
        sys.exit(pyyawl.execute(args.f, args.verbose))


if __name__ == "__main__":
    main()



from typing import Dict, Any
Function = Any

registry: Dict[str, Function] = dict()


def export(*arg, **kwargs):
    """decorator to export functions in the registry
    """

    def export_inner(func):
        registry[kwargs['name']] = func

    return export_inner


if __name__ == "__main__":
    test_name = 'sum'

    @export(name=test_name)
    def func_sum(a, b):
        return a + b

    print(registry[test_name](2, 3))



import papermill as pm
from ..namedregistry import export
from pathlib import Path


@export(name='papermill')
def call_papermill(input_path: Path,
                   output_path: Path,
                   verbose=False,
                   **kwargs):
    if verbose:
        print('executing papermill', input_path, output_path, kwargs)
    return pm.execute_notebook(input_path,
                               output_path,
                               parameters=dict(kwargs['parameters']))



"""Main module."""
from pyyawl.namedregistry import registry
from tqdm import tqdm
from omegaconf import OmegaConf


def execute(file, verbose):
    """Console script for pyyawl."""
    workflow = OmegaConf.load(file)
    execute_pipeline(workflow, verbose)
    return 0


def execute_pipeline(workflow, verbose):
    print('starting workflow', workflow.name)
    for task in tqdm(workflow.tasks):
        if task.operator in registry:
            registry[task.operator](verbose=verbose, **task.arguments)


def generate():
    return """
name: test
description: test description

tasks:
  - operator: echo
    arguments:
      value: yawl
  - operator: echo
    arguments:
      value: world
  - operator: papermill
    arguments:
      input_path: tests/notebooks/sum_test.ipynb
      output_path: tests/notebooks/sum_test_out.ipynb
      parameters:
        a: 8
        b: 4
"""



#!/usr/bin/env python
"""Tests for `pyyawl` package."""

from pyyawl import pyyawl
from pathlib import Path

PATH = Path(__file__).parent


def test_simpleworkflow():
    definition = PATH / 'test_ops.yaml'
    pyyawl.execute(definition, False)
